@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import sys
 from collections import OrderedDict
-from itertools import chain, groupby
+from itertools import chain
 
 import six
 from click.utils import LazyFile
@@ -144,11 +144,6 @@ def as_tuple(ireq):
     return name, version, extras
 
 
-def full_groupby(iterable, key=None):
-    """Like groupby(), but sorts the input on the group key first."""
-    return groupby(sorted(iterable, key=key), key=key)
-
-
 def flat_map(fn, collection):
     """Map a function over a collection and flatten the result by one-level"""
     return chain.from_iterable(map(fn, collection))
